==> swfdec0.4_0.4.5.orig.tar.gz: swfdec-0.4.5/libswfdec-gtk/swfdec_gtk_player.h <==
/* Swfdec
 * Copyright (C) 2007 Benjamin Otte <otte@gnome.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, 
 * Boston, MA  02110-1301  USA
 */

#ifndef _SWFDEC_GTK_PLAYER_H_
#define _SWFDEC_GTK_PLAYER_H_

#include <libswfdec/swfdec.h>

G_BEGIN_DECLS

typedef struct _SwfdecGtkPlayer SwfdecGtkPlayer;
typedef struct _SwfdecGtkPlayerClass SwfdecGtkPlayerClass;

#define SWFDEC_TYPE_GTK_PLAYER                    (swfdec_gtk_player_get_type())
#define SWFDEC_IS_GTK_PLAYER(obj)                 (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SWFDEC_TYPE_GTK_PLAYER))
#define SWFDEC_IS_GTK_PLAYER_CLASS(klass)         (G_TYPE_CHECK_CLASS_TYPE ((klass), SWFDEC_TYPE_GTK_PLAYER))
#define SWFDEC_GTK_PLAYER(obj)                    (G_TYPE_CHECK_INSTANCE_CAST ((obj), SWFDEC_TYPE_GTK_PLAYER, SwfdecGtkPlayer))
#define SWFDEC_GTK_PLAYER_CLASS(klass)            (G_TYPE_CHECK_CLASS_CAST ((klass), SWFDEC_TYPE_GTK_PLAYER, SwfdecGtkPlayerClass))
#define SWFDEC_GTK_PLAYER_GET_CLASS(obj)          (G_TYPE_INSTANCE_GET_CLASS ((obj), SWFDEC_TYPE_GTK_PLAYER, SwfdecGtkPlayerClass))

GType 		swfdec_gtk_player_get_type    	(void);

SwfdecPlayer *	swfdec_gtk_player_new	      	(void);
SwfdecPlayer *	swfdec_gtk_player_new_from_uri	(const char *		uri);

void		swfdec_gtk_player_set_playing 	(SwfdecGtkPlayer *	player,
						 gboolean		playing);
gboolean	swfdec_gtk_player_get_playing 	(SwfdecGtkPlayer *	player);
void		swfdec_gtk_player_set_audio_enabled	
						(SwfdecGtkPlayer *	player,
						 gboolean		enabled);
gboolean	swfdec_gtk_player_get_audio_enabled
						(SwfdecGtkPlayer *	player);
void		swfdec_gtk_player_set_speed	(SwfdecGtkPlayer *	player,
						 double			speed);
double		swfdec_gtk_player_get_speed 	(SwfdecGtkPlayer *	player);



G_END_DECLS
#endif

==> swfdec0.5_0.5.4.orig.tar.gz: swfdec-0.5.4/libswfdec-gtk/swfdec_gtk_player.h <==
/* Swfdec
 * Copyright (C) 2007 Benjamin Otte <otte@gnome.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, 
 * Boston, MA  02110-1301  USA
 */

#ifndef _SWFDEC_GTK_PLAYER_H_
#define _SWFDEC_GTK_PLAYER_H_

#include <libswfdec/swfdec.h>

G_BEGIN_DECLS

typedef struct _SwfdecGtkPlayer SwfdecGtkPlayer;
typedef struct _SwfdecGtkPlayerClass SwfdecGtkPlayerClass;

#define SWFDEC_TYPE_GTK_PLAYER                    (swfdec_gtk_player_get_type())
#define SWFDEC_IS_GTK_PLAYER(obj)                 (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SWFDEC_TYPE_GTK_PLAYER))
#define SWFDEC_IS_GTK_PLAYER_CLASS(klass)         (G_TYPE_CHECK_CLASS_TYPE ((klass), SWFDEC_TYPE_GTK_PLAYER))
#define SWFDEC_GTK_PLAYER(obj)                    (G_TYPE_CHECK_INSTANCE_CAST ((obj), SWFDEC_TYPE_GTK_PLAYER, SwfdecGtkPlayer))
#define SWFDEC_GTK_PLAYER_CLASS(klass)            (G_TYPE_CHECK_CLASS_CAST ((klass), SWFDEC_TYPE_GTK_PLAYER, SwfdecGtkPlayerClass))
#define SWFDEC_GTK_PLAYER_GET_CLASS(obj)          (G_TYPE_INSTANCE_GET_CLASS ((obj), SWFDEC_TYPE_GTK_PLAYER, SwfdecGtkPlayerClass))

GType 		swfdec_gtk_player_get_type    	(void);

SwfdecPlayer *	swfdec_gtk_player_new	      	(SwfdecAsDebugger *	debugger);
SwfdecPlayer *	swfdec_gtk_player_new_from_uri	(const char *		uri);

void		swfdec_gtk_player_set_playing 	(SwfdecGtkPlayer *	player,
						 gboolean		playing);
gboolean	swfdec_gtk_player_get_playing 	(SwfdecGtkPlayer *	player);
void		swfdec_gtk_player_set_audio_enabled	
						(SwfdecGtkPlayer *	player,
						 gboolean		enabled);
gboolean	swfdec_gtk_player_get_audio_enabled
						(SwfdecGtkPlayer *	player);
void		swfdec_gtk_player_set_speed	(SwfdecGtkPlayer *	player,
						 double			speed);
double		swfdec_gtk_player_get_speed 	(SwfdecGtkPlayer *	player);



G_END_DECLS
#endif
